==> jc-1.4.0.tar.gz: java/net/SocketPermission.h <==
// public final class java.net.SocketPermission

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 769239ee5cab6b11 java_net_SocketPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_net_SocketPermission_H_
#define _JC_java_net_SocketPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_net_SocketPermission$sub_refs	_jc_java_net_SocketPermission$sub_refs;
typedef struct _jc_java_net_SocketPermission$sub_nonrefs	_jc_java_net_SocketPermission$sub_nonrefs;
typedef struct _jc_java_net_SocketPermission$refs	_jc_java_net_SocketPermission$refs;
typedef struct _jc_java_net_SocketPermission$nonrefs	_jc_java_net_SocketPermission$nonrefs;
typedef struct _jc_java_net_SocketPermission$object	_jc_java_net_SocketPermission$object;

typedef struct _jc_java_net_SocketPermission$fields_struct	_jc_java_net_SocketPermission$fields_struct;
typedef const struct _jc_java_net_SocketPermission$vmethods	_jc_java_net_SocketPermission$vmethods;
typedef const struct _jc_java_net_SocketPermission$vtable	_jc_java_net_SocketPermission$vtable;
typedef const struct _jc_java_net_SocketPermission$vtype	_jc_java_net_SocketPermission$vtype;

// Class fields structure
struct _jc_java_net_SocketPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_SocketPermission$fields_struct _jc_java_net_SocketPermission$class_fields;

// Constructors
extern void _jc_java_net_SocketPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern jboolean _jc_java_net_SocketPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_net_SocketPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_net_SocketPermission$object *);
extern jint _jc_java_net_SocketPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_net_SocketPermission$object *);
extern jboolean _jc_java_net_SocketPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_security_Permission$object *);
extern struct _jc_java_security_PermissionCollection$object *_jc_java_net_SocketPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_net_SocketPermission$object *);

// Virtual method descriptors
extern _jc_method _jc_java_net_SocketPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_net_SocketPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_net_SocketPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_net_SocketPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_net_SocketPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_java_net_SocketPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_net_SocketPermission$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_net_SocketPermission$object *);
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_security_Permission$object *);
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_net_SocketPermission$object *);
};

// Vtable
struct _jc_java_net_SocketPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_net_SocketPermission$vmethods	java_net_SocketPermission;
};

// Vtype
struct _jc_java_net_SocketPermission$vtype {
	_jc_type			type;
	_jc_java_net_SocketPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_SocketPermission$sub_refs {
	struct _jc_java_lang_String$object	*hostport;
	struct _jc_java_lang_String$object	*actions;
};

// Reference instance fields (object)
struct _jc_java_net_SocketPermission$refs {
    _jc_java_net_SocketPermission$sub_refs	java_net_SocketPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_SocketPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_SocketPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_net_SocketPermission$sub_nonrefs	java_net_SocketPermission;
};

// Object instance structure
struct _jc_java_net_SocketPermission$object {
	_jc_java_net_SocketPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_SocketPermission$vtype	*vtype;
	_jc_java_net_SocketPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_SocketPermission$vtype _jc_java_net_SocketPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_SocketPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_SocketPermission$class_object;

#endif	/* _JC_java_net_SocketPermission_H_ */

==> jc-1.4.6.tar.gz: java/net/SocketPermission.h <==
// public final class java.net.SocketPermission

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 769239ee5cab6b11 java_net_SocketPermission
// @dep_class 2377c76e79058a72 java_security_Permission

// header file dependencies
// @dep_header java_security_Permission

#include "java/security/Permission.h"

#ifndef _JC_java_net_SocketPermission_H_
#define _JC_java_net_SocketPermission_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_java_net_SocketPermission$sub_refs	_jc_java_net_SocketPermission$sub_refs;
typedef struct _jc_java_net_SocketPermission$sub_nonrefs	_jc_java_net_SocketPermission$sub_nonrefs;
typedef struct _jc_java_net_SocketPermission$refs	_jc_java_net_SocketPermission$refs;
typedef struct _jc_java_net_SocketPermission$nonrefs	_jc_java_net_SocketPermission$nonrefs;
typedef struct _jc_java_net_SocketPermission$object	_jc_java_net_SocketPermission$object;

typedef struct _jc_java_net_SocketPermission$fields_struct	_jc_java_net_SocketPermission$fields_struct;
typedef const struct _jc_java_net_SocketPermission$vmethods	_jc_java_net_SocketPermission$vmethods;
typedef const struct _jc_java_net_SocketPermission$vtable	_jc_java_net_SocketPermission$vtable;
typedef const struct _jc_java_net_SocketPermission$vtype	_jc_java_net_SocketPermission$vtype;

// Class fields structure
struct _jc_java_net_SocketPermission$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_net_SocketPermission$fields_struct _jc_java_net_SocketPermission$class_fields;

// Constructors
extern void _jc_java_net_SocketPermission$method$_init$a34354cd9552963f(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_net_SocketPermission$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_net_SocketPermission$method$getActions$a96d1cd349ac27ec(_jc_env *, struct _jc_java_net_SocketPermission$object *) _JC_JCNI_ATTR;
extern jint _jc_java_net_SocketPermission$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_net_SocketPermission$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_net_SocketPermission$method$implies$cbacf9d54b2bb917(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
extern struct _jc_java_security_PermissionCollection$object *_jc_java_net_SocketPermission$method$newPermissionCollection$89e97753129a52a5(_jc_env *, struct _jc_java_net_SocketPermission$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_net_SocketPermission$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_net_SocketPermission$method_info$getActions$a96d1cd349ac27ec;
extern _jc_method _jc_java_net_SocketPermission$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_net_SocketPermission$method_info$implies$cbacf9d54b2bb917;
extern _jc_method _jc_java_net_SocketPermission$method_info$newPermissionCollection$89e97753129a52a5;

// Virtual methods structure
struct _jc_java_net_SocketPermission$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getActions$a96d1cd349ac27ec)(_jc_env *, struct _jc_java_net_SocketPermission$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_net_SocketPermission$object *) _JC_JCNI_ATTR;
	jboolean	(*implies$cbacf9d54b2bb917)(_jc_env *, struct _jc_java_net_SocketPermission$object *, struct _jc_java_security_Permission$object *) _JC_JCNI_ATTR;
	struct _jc_java_security_PermissionCollection$object	*(*newPermissionCollection$89e97753129a52a5)(_jc_env *, struct _jc_java_net_SocketPermission$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_net_SocketPermission$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Permission$vmethods	java_security_Permission;
	_jc_java_net_SocketPermission$vmethods	java_net_SocketPermission;
};

// Vtype
struct _jc_java_net_SocketPermission$vtype {
	_jc_type			type;
	_jc_java_net_SocketPermission$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_net_SocketPermission$sub_refs {
	struct _jc_java_lang_String$object	*hostport;
	struct _jc_java_lang_String$object	*actions;
};

// Reference instance fields (object)
struct _jc_java_net_SocketPermission$refs {
    _jc_java_net_SocketPermission$sub_refs	java_net_SocketPermission;
    _jc_java_security_Permission$sub_refs	java_security_Permission;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_net_SocketPermission$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_net_SocketPermission$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Permission$sub_nonrefs	java_security_Permission;
    _jc_java_net_SocketPermission$sub_nonrefs	java_net_SocketPermission;
};

// Object instance structure
struct _jc_java_net_SocketPermission$object {
	_jc_java_net_SocketPermission$refs	refs[0];
	_jc_word		lockword;
	_jc_java_net_SocketPermission$vtype	*vtype;
	_jc_java_net_SocketPermission$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_net_SocketPermission$vtype _jc_java_net_SocketPermission$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_net_SocketPermission, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_net_SocketPermission$class_object;

#endif	/* _JC_java_net_SocketPermission_H_ */
